ImageDescription
================

.. currentmodule:: toasty.image

.. autoclass:: ImageDescription
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageDescription.dtype
      ~ImageDescription.height
      ~ImageDescription.mode
      ~ImageDescription.shape
      ~ImageDescription.wcs
      ~ImageDescription.width

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageDescription.ensure_negative_parity
      ~ImageDescription.flip_parity
      ~ImageDescription.get_parity_sign

   .. rubric:: Attributes Documentation

   .. autoattribute:: dtype
   .. autoattribute:: height
   .. autoattribute:: mode
   .. autoattribute:: shape
   .. autoattribute:: wcs
   .. autoattribute:: width

   .. rubric:: Methods Documentation

   .. automethod:: ensure_negative_parity
   .. automethod:: flip_parity
   .. automethod:: get_parity_sign
